# Implementations Based on _pygls_

| Name                     | Maintainer                                                            | Repository (optional)                                                      | Notes                                                                                                                         |
|--------------------------|-----------------------------------------------------------------------|----------------------------------------------------------------------------|-------------------------------------------------------------------------------------------------------------------------------|
| _Anakin Language Server_ | [Andrii Kolomoiets](https://github.com/muffinmad) | [anakin-language-server](https://github.com/muffinmad/anakin-language-server) | Yet another Jedi Python language server |
| _Cmake Language Server_  | [Regen100](https://github.com/regen100)                               | [cmake-language-server](https://github.com/regen100/cmake-language-server) | CMake LSP Implementation
| _Codify Language Server_ | [Open Law Library](http://www.openlawlib.org/)                        | &nbsp;                                                                     | Used in our VS Code extension, _[Codify](https://marketplace.visualstudio.com/items?itemName=openlawlibrary.open-law-codify)_ |
| _Jedi Language Server_   | [Samuel Roeca](https://softwarejourneyman.com/pages/about.html#about) | [jedi-language-server](https://github.com/pappasam/jedi-language-server)   | Python language server wrapping [Jedi](https://github.com/davidhalter/jedi)                                                   |
| _zc.buildout Language Server_   | [Jérome Perrin](https://github.com/perrinjerome) | [zc.buildout.languageserver](https://github.com/perrinjerome/vscode-zc-buildout)   | Language server for [zc.buildout](http://docs.buildout.org/en/latest/) profiles.  |

## _(alphabetic by name, maintainer)_
